Struct std::simd::b8x2
[−]
[src]
#[repr(simd)]pub struct b8x2(_, _);
A 16-bit wide vector with 2 bool lanes.
Methods
impl b8x2[src]
pub const fn new(x0: bool, x1: bool) -> b8x2[src]
Creates a new instance with each vector elements initialized with the provided values.
pub const fn lanes() -> usize[src]
Returns the number of vector lanes.
pub const fn splat(value: bool) -> b8x2[src]
Constructs a new instance with each element initialized to
value.
pub fn extract(self, index: usize) -> bool[src]
pub unsafe fn extract_unchecked(self, index: usize) -> bool[src]
Extracts the value at index.
If index >= Self::lanes() the behavior is undefined.
pub fn replace(self, index: usize, new_value: bool) -> b8x2[src]
Returns a new vector where the value at index is replaced by new_value.
Panics
If index >= Self::lanes().
pub unsafe fn replace_unchecked(self, index: usize, new_value: bool) -> b8x2[src]
Returns a new vector where the value at index is replaced by new_value.
Panics
If index >= Self::lanes().
impl b8x2[src]
pub fn and(self) -> bool[src]
Lane-wise bitwise and of the vector elements.
pub fn or(self) -> bool[src]
Lane-wise bitwise or of the vector elements.
pub fn xor(self) -> bool[src]
Lane-wise bitwise xor of the vector elements.
impl b8x2[src]
pub fn all(self) -> bool[src]
Are all vector lanes true?
pub fn any(self) -> bool[src]
Is any vector lanes true?
pub fn none(self) -> bool[src]
Are all vector lanes false?
impl b8x2[src]
pub fn eq(self, other: b8x2) -> b8x2[src]
Lane-wise equality comparison.
pub fn ne(self, other: b8x2) -> b8x2[src]
Lane-wise inequality comparison.
pub fn lt(self, other: b8x2) -> b8x2[src]
Lane-wise less-than comparison.
pub fn le(self, other: b8x2) -> b8x2[src]
Lane-wise less-than-or-equals comparison.
pub fn gt(self, other: b8x2) -> b8x2[src]
Lane-wise greater-than comparison.
pub fn ge(self, other: b8x2) -> b8x2[src]
Lane-wise greater-than-or-equals comparison.