Struct std::simd::f32x8
[−]
[src]
#[repr(simd)]pub struct f32x8(_, _, _, _, _, _, _, _);
A 256-bit vector with 8 f32 lanes.
Methods
impl f32x8[src]
pub const fn new(
x0: f32,
x1: f32,
x2: f32,
x3: f32,
x4: f32,
x5: f32,
x6: f32,
x7: f32
) -> f32x8[src]
x0: f32,
x1: f32,
x2: f32,
x3: f32,
x4: f32,
x5: f32,
x6: f32,
x7: f32
) -> f32x8
Creates a new instance with each vector elements initialized with the provided values.
pub const fn lanes() -> usize[src]
Returns the number of vector lanes.
pub const fn splat(value: f32) -> f32x8[src]
Constructs a new instance with each element initialized to
value.
pub fn extract(self, index: usize) -> f32[src]
pub unsafe fn extract_unchecked(self, index: usize) -> f32[src]
Extracts the value at index.
If index >= Self::lanes() the behavior is undefined.
pub fn replace(self, index: usize, new_value: f32) -> f32x8[src]
Returns a new vector where the value at index is replaced by new_value.
Panics
If index >= Self::lanes().
pub unsafe fn replace_unchecked(self, index: usize, new_value: f32) -> f32x8[src]
Returns a new vector where the value at index is replaced by new_value.
Panics
If index >= Self::lanes().
impl f32x8[src]
pub fn store_aligned(self, slice: &mut [f32])[src]
Writes the values of the vector to the slice.
Panics
If slice.len() < Self::lanes() or &slice[0] is not
aligned to an align_of::<Self>() boundary.
pub fn store_unaligned(self, slice: &mut [f32])[src]
pub unsafe fn store_aligned_unchecked(self, slice: &mut [f32])[src]
Writes the values of the vector to the slice.
Precondition
If slice.len() < Self::lanes() or &slice[0] is not
aligned to an align_of::<Self>() boundary, the behavior is
undefined.
pub unsafe fn store_unaligned_unchecked(self, slice: &mut [f32])[src]
Writes the values of the vector to the slice.
Precondition
If slice.len() < Self::lanes() the behavior is undefined.
pub fn load_aligned(slice: &[f32]) -> f32x8[src]
Instantiates a new vector with the values of the slice.
Panics
If slice.len() < Self::lanes() or &slice[0] is not aligned
to an align_of::<Self>() boundary.
pub fn load_unaligned(slice: &[f32]) -> f32x8[src]
pub unsafe fn load_aligned_unchecked(slice: &[f32]) -> f32x8[src]
Instantiates a new vector with the values of the slice.
Precondition
If slice.len() < Self::lanes() or &slice[0] is not aligned
to an align_of::<Self>() boundary, the behavior is undefined.
pub unsafe fn load_unaligned_unchecked(slice: &[f32]) -> f32x8[src]
Instantiates a new vector with the values of the slice.
Precondition
If slice.len() < Self::lanes() the behavior is undefined.
impl f32x8[src]
pub fn eq(self, other: f32x8) -> b8x8[src]
Lane-wise equality comparison.
pub fn ne(self, other: f32x8) -> b8x8[src]
Lane-wise inequality comparison.
pub fn lt(self, other: f32x8) -> b8x8[src]
Lane-wise less-than comparison.
pub fn le(self, other: f32x8) -> b8x8[src]
Lane-wise less-than-or-equals comparison.
pub fn gt(self, other: f32x8) -> b8x8[src]
Lane-wise greater-than comparison.
pub fn ge(self, other: f32x8) -> b8x8[src]
Lane-wise greater-than-or-equals comparison.
impl f32x8[src]
pub fn sum(self) -> f32[src]
Lane-wise addition of the vector elements.
pub fn product(self) -> f32[src]
Lane-wise multiplication of the vector elements.
impl f32x8[src]
pub fn max(self) -> f32[src]
Largest vector value.
pub fn min(self) -> f32[src]
Smallest vector value.